AnalyticsReport class

Constructors

AnalyticsReport({int totalAttempts = 0, String? mostFailedField, Map<String, int> fieldFailureCounts = const {}})
const

Properties

fieldFailureCounts → Map<String, int>
final
hashCode → int
The hash code for this object.
no setterinherited
mostFailedField → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAttempts → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited