SmartFormGuard class

A smart wrapper widget that provides form state management to its descendants.

Wraps your form and provides a FormController via SmartFormGuard.of. Handles auto-saving, restoration, and analytics.

Inheritance

Constructors

SmartFormGuard({Key? key, required String formId, required Widget child, bool autoSave = true, bool autoRestore = true, FormStorage? storage})
const

Properties

autoRestore bool
Whether to automatically restore saved state on initialization. Defaults to true.
final
autoSave bool
Whether to automatically save form state on changes. Defaults to true.
final
child Widget
The widget below this widget in the tree.
final
formId String
Unique identifier for this form. Used as the key for storage persistence.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storage FormStorage?
Optional custom storage provider. Defaults to SharedPrefsFormStorage.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SmartFormGuard>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) FormController